Prepare community contacts scaling from workplace scaling
Source:R/class_npi.R
make_community_scaling.RdHelper function to determine the (uniform) community contacts scaling, based on the scaling of workplace contacts. Higher mean workplace contacts scaling leads to higher community contacts scaling. Workplace contacts scaling mean is not weighted by worker counts.